@@ -1,5 +1,8 @@
 package RPC::ExtDirect::Demo::PollProvider;
 
+use strict;
+use warnings;
+
 use POSIX 'strftime';
 
 use RPC::ExtDirect;
@@ -41,7 +44,7 @@ Alexander Tokarev E<lt>tokarev@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2011-2012 by Alexander Tokarev. 
+Copyright (c) 2011-2014 by Alexander Tokarev. 
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See L<perlartistic>.
